@@ -13,8 +13,7 @@ except ImportError:
 
 from tiddlyweb.filters import parse_for_filters
 from tiddlyweb.model.bag import Bag
-from tiddlyweb.model.tiddler import Tiddler
-from tiddlyweb.store import NoBagError, StoreError, NoTiddlerError
+from tiddlyweb.store import NoBagError
 from tiddlyweb import control
 from tiddlyweb.web.handler.recipe import get_tiddlers
 from tiddlyweb.web.handler.tiddler import get as get_tiddler
@@ -25,11 +24,6 @@ from tiddlywebplugins.utils import require_any_user
 
 from tiddlywebplugins.tiddlyspace.web import (determine_host,
         determine_space, determine_space_recipe)
-from tiddlywebplugins.tiddlyspace.space import Space
-
-
-SPACE_SERVER_SETTINGS = 'ServerSettings'
-DEFAULT_NEWUSER_APP = 'apps'
 
 
 def friendly_uri(environ, start_response):
@@ -78,13 +72,14 @@ def get_space_tiddlers(environ, start_response):
     whatever the reqeusted representation is. Choose recipe
     based on membership status.
     """
-    space_name = _setup_friendly_environ(environ)
+    _setup_friendly_environ(environ)
     serializer, _ = get_serialize_type(environ)
-    # If we are a wiki read ServerSettings, but ignore index
+
+    _extra_query_update(environ)
+
     if ('betaserialization' in serializer
             or 'betalazyserialization' in serializer):
-        _, lazy = update_space_settings(environ, space_name)
-        if lazy:
+        if environ['tiddlyweb.space_settings']['lazy']:
             environ['tiddlyweb.type'] = 'text/x-ltiddlywiki'
     return get_tiddlers(environ, start_response)
 
@@ -102,6 +97,7 @@ def home(environ, start_response):
     return serve_space(environ, start_response, http_host)
 
 
+
 def serve_space(environ, start_response, http_host):
     """
     Serve a space determined from the current virtual host and user.
@@ -112,90 +108,35 @@ def serve_space(environ, start_response, http_host):
     environ['wsgiorg.routing_args'][1]['recipe_name'] = recipe_name.encode(
             'UTF-8')
     _, mime_type = get_serialize_type(environ)
-    index, lazy = update_space_settings(environ, space_name)
+
+    _extra_query_update(environ)
+
+    index = environ['tiddlyweb.space_settings']['index']
     if index:
         environ['wsgiorg.routing_args'][1]['tiddler_name'] = index.encode(
                 'UTF-8')
         return get_tiddler(environ, start_response)
     if 'text/html' in mime_type:
-        if lazy:
+        if environ['tiddlyweb.space_settings']['lazy']:
             environ['tiddlyweb.type'] = 'text/x-ltiddlywiki'
         else:
             environ['tiddlyweb.type'] = 'text/x-tiddlywiki'
     return get_tiddlers(environ, start_response)
 
 
-def _figure_default_index(environ, bag_name, space, index=None):
+def _extra_query_update(environ):
     """
-    if an app hasn't been specified, check whether the space is new or old.
-    old users should get the old default: TiddlyWiki, new users should get
-    the new default: the app switcher. The presence of a spaceSetupFlag
-    tiddler is the test for this.
+    If extra_query is set via ServerSettings, then process that
+    information as query strings and filters.
     """
-    store = environ['tiddlyweb.store']
-    if not index and space.name != 'frontpage':
-        setupFlag = Tiddler('%sSetupFlag' % space.name, bag_name)
-        try:
-            setupFlag = store.get(setupFlag)
-        except NoTiddlerError:
-            setupFlag.bag = space.private_bag()
-            try:
-                setupFlag = store.get(setupFlag)
-            except NoTiddlerError:
-                index = DEFAULT_NEWUSER_APP
-
-    return index
-
-
-def update_space_settings(environ, name):
-    """
-    Read a tiddler named by SPACE_SERVER_SETTINGS in the current
-    space's public bag. Parse each line as a key:value pair which
-    is then injected tiddlyweb.query. The goal here is to allow
-    a space member to force incoming requests to use specific
-    settings, such as alpha or externalized.
-    """
-    store = environ['tiddlyweb.store']
-    space = Space(name)
-    bag_name = space.public_bag()
-    tiddler = Tiddler(SPACE_SERVER_SETTINGS, bag_name)
-    data_text = ''
-    try:
-        tiddler = store.get(tiddler)
-        data_text = tiddler.text
-    except StoreError:
-        return _figure_default_index(environ, bag_name, space), False
-
-    query_strings = []
-    index = ''
-    lazy = False
-    for line in data_text.split('\n'):
-        try:
-            key, value = line.split(':', 1)
-            key = key.rstrip().lstrip()
-            value = value.rstrip().lstrip()
-            if key == 'index':
-                index = value
-            elif key == 'lazy':
-                if value.lower() == 'true':
-                    lazy = True
-            else:
-                query_strings.append('%s=%s' % (key, value))
-        except ValueError:
-            pass
-
-    index = _figure_default_index(environ, bag_name, space, index)
-
-    query_string = ';'.join(query_strings)
-
-    filters, leftovers = parse_for_filters(query_string, environ)
-    environ['tiddlyweb.filters'].extend(filters)
-    query_data = parse_qs(leftovers, keep_blank_values=True)
-    environ['tiddlyweb.query'].update(dict(
-        [(key, [value for value in values])
-            for key, values in query_data.items()]))
-
-    return index, lazy
+    extra_query = environ['tiddlyweb.space_settings']['extra_query']
+    if extra_query:
+        filters, leftovers = parse_for_filters(extra_query, environ)
+        environ['tiddlyweb.filters'].extend(filters)
+        query_data = parse_qs(leftovers, keep_blank_values=True)
+        environ['tiddlyweb.query'].update(dict(
+            [(key, [value for value in values])
+                for key, values in query_data.items()]))
 
 
 def _setup_friendly_environ(environ):
@@ -213,4 +154,3 @@ def _setup_friendly_environ(environ):
     recipe_name = determine_space_recipe(environ, space_name)
     environ['wsgiorg.routing_args'][1]['recipe_name'] = recipe_name.encode(
         'UTF-8')
-    return space_name
